﻿;==========================================================================================================================================================
; Add a new category to the database
;==========================================================================================================================================================

Procedure AddCategory()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if an existing window is opened
  ;------------------------------------------------------------------------------------------------
  
  If Program\WindowMutex <> #True
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the data form window
    ;----------------------------------------------------------------------------------------------
    
    If Window_PiccyCategory()
      
      ;--------------------------------------------------------------------------------------------
      ; Window was opened so set mutex to prevent other windows from opening
      ;--------------------------------------------------------------------------------------------
      
      Program\WindowMutex = #True
      
      ;--------------------------------------------------------------------------------------------
      ; Prevent user input on the main window
      ;--------------------------------------------------------------------------------------------
      
      DisableWindow(#Window_PiccyDb, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; Add the hover gadgets to this window
      ;--------------------------------------------------------------------------------------------
      
      AddHoverGadget(GadgetID(#Gadget_PiccyCategory_SaveCategory))
      
      AddHoverGadget(GadgetID(#Gadget_PiccyCategory_ExitCategory))
      
      ;--------------------------------------------------------------------------------------------
      ; Add the fast form close keyboard shortcut
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_PiccyCategory, #PB_Shortcut_Escape,                   #Shortcut_CloseCategory)

      AddKeyboardShortcut(#Window_PiccyCategory, #PB_Shortcut_Alt    | #PB_Shortcut_S,  #Shortcut_SaveCategory)

      AddKeyboardShortcut(#Window_PiccyCategory, #PB_Shortcut_Alt    | #PB_Shortcut_X,  #Shortcut_ExitCategory)
      
      ;--------------------------------------------------------------------------------------------
      ; Set the last window message for the closure routine later
      ;--------------------------------------------------------------------------------------------
      
      Program\LastWindow = "Add A New Category"
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the data window
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTitle(#Window_PiccyCategory, Program\LastWindow)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_PiccyCategory_lCategory, "Add a new category above.")
      
      ;--------------------------------------------------------------------------------------------
      ; Get the last record number in the database and give the next probable record number
      ;--------------------------------------------------------------------------------------------
      
      NextRecord.i = Val(LastRecord("Record", "Categories")) + 1
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_PiccyCategory_RecordNumber, "Record No: " + Str(NextRecord.i))
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the main window
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings", "Info", Program\LastWindow, "AddCategory")
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the data form window is topmost
      ;--------------------------------------------------------------------------------------------
      
      SetActiveWindow(#Window_PiccyCategory)
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the version field is selected
      ;--------------------------------------------------------------------------------------------
      
      SetActiveGadget(#Gadget_PiccyCategory_Category)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      HideWindow(#Window_PiccyCategory, #False)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings", "Error", "The program window could not be opened.", "AddCategory")
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings", "Warn", "Another program window is still open, close that one first.", "AddCategory")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 46
; FirstLine = 87
; Folding = -
; EnableXP
; HideErrorLog