﻿;==========================================================================================================================================================
; Add a new picture and details to the database
;==========================================================================================================================================================

Procedure AddNewPicture()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if an existing window is opened
  ;------------------------------------------------------------------------------------------------
  
  If Program\WindowMutex <> #True
    
    ;----------------------------------------------------------------------------------------------
    ; Try to open the data form window
    ;----------------------------------------------------------------------------------------------
    
    If Window_PiccyData()
      
      ;--------------------------------------------------------------------------------------------
      ; Window was opened so set mutex to prevent other windows from opening
      ;--------------------------------------------------------------------------------------------
      
      Program\WindowMutex = #True
      
      ;--------------------------------------------------------------------------------------------
      ; Prevent user input on the main window
      ;--------------------------------------------------------------------------------------------
      
      DisableWindow(#Window_PiccyDb, #True)
      
      ;--------------------------------------------------------------------------------------------
      ; Setup the common add window message
      ;--------------------------------------------------------------------------------------------
      
      Message.s = "Add A New Picture"
      
      ;--------------------------------------------------------------------------------------------
      ; Set the last window message for the closure routine later
      ;--------------------------------------------------------------------------------------------
      
      Program\LastWindow = Message.s
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the data window
      ;--------------------------------------------------------------------------------------------
      
      SetWindowTitle(#Window_PiccyData, Message.s)
      
      ;--------------------------------------------------------------------------------------------
      ; Add this forms' hover gadgets
      ;--------------------------------------------------------------------------------------------
      
      AddHoverGadget(GadgetID(#Gadget_PiccyData_Save))
      
      AddHoverGadget(GadgetID(#Gadget_PiccyData_Load))
      
      AddHoverGadget(GadgetID(#Gadget_PiccyData_Exit))
      
      ;--------------------------------------------------------------------------------------------
      ; Add the fast form close keyboard shortcut
      ;--------------------------------------------------------------------------------------------
      
      AddKeyboardShortcut(#Window_PiccyData, #PB_Shortcut_Escape,                   #Shortcut_CloseData)

      AddKeyboardShortcut(#Window_PiccyData, #PB_Shortcut_Alt    | #PB_Shortcut_S,  #Shortcut_SaveData)

      AddKeyboardShortcut(#Window_PiccyData, #PB_Shortcut_Alt    | #PB_Shortcut_X,  #Shortcut_ExitData)
      
      ;--------------------------------------------------------------------------------------------
      ; Remove borders from various gadgets
      ;--------------------------------------------------------------------------------------------
      
      RemoveBorders(#Gadget_PiccyData_Comment)

      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillCombo(#Gadget_PiccyData_Category, "SELECT DISTINCT Category FROM Categories ORDER BY Category",     #Image_Combo_Category)
      
      AddGadgetItem(#Gadget_PiccyData_Category, #FirstItem, #EmptyString, ImageID(#Image_Combo_Empty))
      
      SetGadgetState(#Gadget_PiccyData_Category, #FirstItem)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      CategoryString.s = GetGadgetText(#Gadget_PiccyDb_Category)
      
      If CategoryString.s <> "All pictures" And CategoryString.s <> "No category" And CategoryString.s <> "Favourites" And CategoryString.s <> "Locked pictures" And CategoryString.s <> "Deleted pictures" And CategoryString.s <> #EmptyString
        
        SetGadgetText(#Gadget_PiccyData_Category, CategoryString.s)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillCombo(#Gadget_PiccyData_Subcategory, "SELECT DISTINCT Subcategory FROM PictureInfo ORDER BY Subcategory",     #Image_Combo_Subcategory)
      
      AddGadgetItem(#Gadget_PiccyData_Subcategory, #FirstItem, #EmptyString, ImageID(#Image_Combo_Empty))
      
      SetGadgetState(#Gadget_PiccyData_Subcategory, #FirstItem)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillCombo(#Gadget_PiccyData_Artist, "SELECT DISTINCT Artist FROM PictureInfo ORDER BY Artist",          #Image_Combo_Artist)
      
      AddGadgetItem(#Gadget_PiccyData_Artist, #FirstItem, #EmptyString, ImageID(#Image_Combo_Empty))
      
      SetGadgetState(#Gadget_PiccyData_Artist, #FirstItem)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillCombo(#Gadget_PiccyData_Copyright, "SELECT DISTINCT Copyright FROM PictureInfo ORDER BY Copyright", #Image_Combo_Copyright)
      
      AddGadgetItem(#Gadget_PiccyData_Copyright, #FirstItem, #EmptyString, ImageID(#Image_Combo_Empty))

      SetGadgetState(#Gadget_PiccyData_Copyright, #FirstItem)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      FillCombo(#Gadget_PiccyData_Homepage, "SELECT DISTINCT Homepage FROM PictureInfo ORDER BY Homepage",    #Image_Combo_Homepage)
      
      AddGadgetItem(#Gadget_PiccyData_Homepage, #FirstItem, #EmptyString, ImageID(#Image_Combo_Empty))
      
      SetGadgetState(#Gadget_PiccyData_Homepage, #FirstItem)
      
      ;--------------------------------------------------------------------------------------------
      ; Get the last record number in the database and give the next probable record number
      ;--------------------------------------------------------------------------------------------
      
      NextRecord.i = Val(LastRecord("Record_Id", "PictureInfo")) + 1
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetText(#Gadget_PiccyData_Record_Id, "Record No: " + Str(NextRecord.i)  + "?")
      
      ;--------------------------------------------------------------------------------------------
      ; Show new record number and status in the main window
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings", "Info", Message.s  + " to the picture database")
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the data form window is topmost
      ;--------------------------------------------------------------------------------------------
      
      SetActiveWindow(#Window_PiccyData)
      
      ;--------------------------------------------------------------------------------------------
      ; Make sure the version field is selected
      ;--------------------------------------------------------------------------------------------
      
      SetActiveGadget(#Gadget_PiccyData_Title)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings", "Error", "The program window could not be opened.", "AddNewPicture()")
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings", "Warn", "Another program window is still open, close that one first.", "AddNewPicture()")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 123
; FirstLine = 113
; Folding = -
; EnableXP