﻿;==========================================================================================================================================================
; Export appointment data to a standard XML file
;==========================================================================================================================================================

Procedure ExportPictures()
  
  ;------------------------------------------------------------------------------------------------
  ; Process the current table name
  ;------------------------------------------------------------------------------------------------
  
  DatabaseQuery.s = "SELECT m.Title, m.Artist, m.Copyright, m.Homepage, m.Category, m.Subcategory, "
  
  DatabaseQuery.s + "m.Comment, m.Directory, m.Filename, m.MD5Fingerprint, m.Created, m.Modified, "
  
  DatabaseQuery.s + "m.Accessed, m.Archived, m.Horizontal, m.Vertical, m.Depth, m.Favourite, "
  
  DatabaseQuery.s + "m.Locked, m.Deleted, n.Picture "
  
  DatabaseQuery.s + "FROM PictureInfo AS m, PictureData AS n "
  
  DatabaseQuery.s + "WHERE n.Record_Id = m.Record_Id "      
  
  ;------------------------------------------------------------------------------------------------
  ;
  ;------------------------------------------------------------------------------------------------
  
  If DatabaseQuery(Program\DatabaseHandle,  DatabaseQuery.s)
    
    ;----------------------------------------------------------------------------------------------
    ; Process the next returned row
    ;----------------------------------------------------------------------------------------------
    
    While NextDatabaseRow(Program\DatabaseHandle)
      
      ;--------------------------------------------------------------------------------------------
      ; Have we created this XML tree already?
      ;--------------------------------------------------------------------------------------------
      
      If *XmlTree = 0
        
        ;------------------------------------------------------------------------------------------
        ; Creates a new empty XML tree identified by the #XML number
        ;------------------------------------------------------------------------------------------
        
        *XmlTree = CreateXML(#PB_Any)
        
        ;------------------------------------------------------------------------------------------
        ; Creates a new XML node and inserts it into the given parent node. 
        ;------------------------------------------------------------------------------------------
        
        *RootXmlNode = CreateXMLNode(RootXMLNode(*XmlTree), #EmptyString)
        
        ;------------------------------------------------------------------------------------------
        ; Changes the tagname of the given XML node (root in this case)
        ;------------------------------------------------------------------------------------------
        
        SetXMLNodeName(*RootXmlNode, "PiccyDb")
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Creates a new XML node and inserts it into main XML node of the tree.
      ;--------------------------------------------------------------------------------------------
      
      *RowNode = CreateXMLNode(MainXMLNode(*XmlTree), #EmptyString)
      
      ;--------------------------------------------------------------------------------------------
      ; If the main node was created, dump all the columns using the column names as node names
      ;--------------------------------------------------------------------------------------------
      
      If *RowNode
        
        ;------------------------------------------------------------------------------------------
        ; Changes the tagname of the given XML node (main node in this case)
        ;------------------------------------------------------------------------------------------
        
        SetXMLNodeName(*RowNode, "PictureItem")
        
        ;------------------------------------------------------------------------------------------
        ; Get the column names and write them first
        ;------------------------------------------------------------------------------------------
        
        NumberOfColumns.i = DatabaseColumns(Program\DatabaseHandle)
        
        ;------------------------------------------------------------------------------------------
        ; Iterate through the columns
        ;------------------------------------------------------------------------------------------
        
        For ColumnNamesLoop.i = 0 To NumberOfColumns.i -1
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
          CurrentColumn.s = DatabaseColumnName(Program\DatabaseHandle, ColumnNamesLoop.i)
          
          ;----------------------------------------------------------------------------------------
          ; Creates a new XML node and inserts it into main XML node of the tree.
          ;----------------------------------------------------------------------------------------
          
          *ColumnNode = CreateXMLNode(*RowNode, #EmptyString)
          
          ;----------------------------------------------------------------------------------------
          ; Set the node name to be the current column name
          ;----------------------------------------------------------------------------------------
          
          SetXMLNodeName(*ColumnNode, CurrentColumn.s)
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
          If CurrentColumn.s = "Picture"
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            Picture_Length.i    = DatabaseColumnSize(Program\DatabaseHandle,  ColumnNamesLoop.i)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            If Picture_Length.i
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              *PhotoBlobBuffer  = AllocateMemory(Picture_Length.i)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              BlobResult.i      = GetDatabaseBlob(Program\DatabaseHandle, ColumnNamesLoop.i, *PhotoBlobBuffer, Picture_Length.i)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              If BlobResult.i
                
                ;----------------------------------------------------------------------------------
                ; Enough room for message size and expansion
                ;----------------------------------------------------------------------------------
                
                EncodedSize.i   = Picture_Length.i * 1.35
                
                If EncodedSize.i < 64
                  
                  EncodedSize.i = 64
                  
                EndIf
                
                ;----------------------------------------------------------------------------------
                ; Now create the encoding space buffer
                ;----------------------------------------------------------------------------------
                
                *EncodedBuffer  = AllocateMemory(EncodedSize.i)
                
                ;----------------------------------------------------------------------------------
                ; Encode the text now
                ;----------------------------------------------------------------------------------
                
                ActualBytes.i   = Base64Encoder(*PhotoBlobBuffer, Picture_Length.i, *EncodedBuffer, EncodedSize.i)

                ;----------------------------------------------------------------------------------
                ; Did we get anything encoded?
                ;----------------------------------------------------------------------------------
                
                If ActualBytes.i
                  
;                 Debug "BKK"
                  
                  SetXMLNodeText(*ColumnNode, PeekS(*EncodedBuffer, ActualBytes.i, #PB_Ascii))
                  
                Else
                  
                  SetInfoBarArea("Headings",  "Error",  " No bytes of data were found encoded in the buffer", "ExportPictures()")
                  
                EndIf
                
                ;----------------------------------------------------------------------------------
                ; 
                ;----------------------------------------------------------------------------------
                
                If *PhotoBlobBuffer
                  
                  ;--------------------------------------------------------------------------------
                  ; Free the file buffer space 
                  ;--------------------------------------------------------------------------------
                  
                  FreeMemory(*PhotoBlobBuffer)
                  
                EndIf
                
                ;----------------------------------------------------------------------------------
                ; Free encoding space 
                ;----------------------------------------------------------------------------------
                
                If *EncodedBuffer
                  
                  ;--------------------------------------------------------------------------------
                  ; Free encoding space 
                  ;--------------------------------------------------------------------------------
                  
                  FreeMemory(*EncodedBuffer)
                  
                EndIf
                
                ;----------------------------------------------------------------------------------
                ; 
                ;----------------------------------------------------------------------------------
                
              Else
                
                SetInfoBarArea("Headings",  "Error",  "Could not get the picture data from the database or the query was faulty", "ExportPictures()")
                
              EndIf
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
            Else
              
              SetInfoBarArea("Headings",  "Error",  "Could not get the picture data from the database or the query was faulty", "ExportPictures()")
              
            EndIf
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
          Else
            
            SetXMLNodeText(*ColumnNode, TextToXml(GetDatabaseString(Program\DatabaseHandle,  ColumnNamesLoop.i)))  
            
          EndIf
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
        Next                                                                                                  ; Next column
        
        ;------------------------------------------------------------------------------------------
        ; Main node wasn't created, exit out of this procedure
        ;------------------------------------------------------------------------------------------
        
      Else
        
        ; XML creation error
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Wend
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    FinishDatabaseQuery(Program\DatabaseHandle)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If *XmlTree
      
      FormatXML(*XmlTree, #PB_XML_ReFormat)
      
      SaveXML(*XmlTree, Program\TemporaryDirectory + #Program + "_Export_File.xml")
      
      FreeXML(*XmlTree)
      
      ;--------------------------------------------------------------------------------------------
      ; XML data was saved
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Headings",  "Info",  "Exported: "  + #Program + "_Export_File.xml to: "  + Program\TemporaryDirectory, "ExportPictures()")

      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; The database query has failed for some reason
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Error",  "Database query failed or was empty", "ExportPictures()")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure
; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 104
; FirstLine = 101
; Folding = -
; EnableXP
; CompileSourceDirectory