﻿;==========================================================================================================================================================
; Show all the pictures in the database
;==========================================================================================================================================================

Procedure SearchPictures()
  
  ;------------------------------------------------------------------------------------------------
  ; Clear the list for the next search
  ;------------------------------------------------------------------------------------------------
  
  ClearGadgetItems(#Gadget_PiccyDb_Titles)
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  SearchType.s     = GetGadgetText(#Gadget_PiccyDb_searchtype)
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  SearchText.s     = KillQuote(GetGadgetText(#Gadget_PiccyDb_search))
  
  ;------------------------------------------------------------------------------------------------
  ; Alias the search type text to SQLite operators
  ;------------------------------------------------------------------------------------------------
  
  SearchCommand.s = SetSearchQuery(SearchType.s, SearchText.s)
  
  ;------------------------------------------------------------------------------------------------
  ; Search all fields
  ;------------------------------------------------------------------------------------------------
  
  If SearchText.s <> #EmptyString
    
    ;----------------------------------------------------------------------------------------------
    ; Make the compound query
    ;----------------------------------------------------------------------------------------------
    
    DatabaseQuery.s = "SELECT * FROM PictureInfo WHERE ("
    
    DatabaseQuery.s + " Title"              + SearchCommand.s
    
    DatabaseQuery.s + " OR Artist"          + SearchCommand.s
    
    DatabaseQuery.s + " OR Copyright"       + SearchCommand.s
    
    DatabaseQuery.s + " OR Homepage"        + SearchCommand.s
    
    DatabaseQuery.s + " OR Category"        + SearchCommand.s
    
    DatabaseQuery.s + " OR Comment"         + SearchCommand.s
    
    DatabaseQuery.s + " OR Directory"       + SearchCommand.s
    
    DatabaseQuery.s + " OR Filename"        + SearchCommand.s
    
    DatabaseQuery.s + " OR MD5Fingerprint"  + SearchCommand.s
    
    DatabaseQuery.s + " OR Created"         + SearchCommand.s
    
    DatabaseQuery.s + " OR Modified"        + SearchCommand.s
    
    DatabaseQuery.s + " OR Accessed"        + SearchCommand.s
    
    DatabaseQuery.s + " OR Archived"        + SearchCommand.s
    
    DatabaseQuery.s + " OR Horizontal"      + SearchCommand.s
    
    DatabaseQuery.s + " OR Vertical"        + SearchCommand.s
    
    DatabaseQuery.s + " OR Depth"           + SearchCommand.s
    
    DatabaseQuery.s + " OR Favourite"       + SearchCommand.s
    
    DatabaseQuery.s + " OR Locked"          + SearchCommand.s
    
    DatabaseQuery.s + " OR Deleted"         + SearchCommand.s
    
    DatabaseQuery.s + " OR Record_Id"       + SearchCommand.s
    
    DatabaseQuery.s + ")"
    
    DatabaseQuery.s + " ORDER BY Title"
    
  ElseIf SearchText.s = #EmptyString
    
    DatabaseQuery.s = "SELECT * FROM PictureInfo ORDER BY Title"
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; Data display routine for Search Addresses 
  ;------------------------------------------------------------------------------------------------
  
  PseudoCounter.i = 0
  
  ;------------------------------------------------------------------------------------------------
  ; Was the compiled binary SQLite statement generation successfull?
  ;------------------------------------------------------------------------------------------------
  
  If DatabaseQuery(Program\DatabaseHandle, DatabaseQuery.s) <> #DatabaseQueryFail
    
    ;----------------------------------------------------------------------------------------------
    ; Lock the list form to prevent it greying out or flickering during the update
    ;----------------------------------------------------------------------------------------------
    
    LockWindowUpdate_(GadgetID(#Gadget_PiccyDb_Titles))
    
    ;----------------------------------------------------------------------------------------------
    ; Step through all available returned records
    ;----------------------------------------------------------------------------------------------
    
    While NextDatabaseRow(Program\DatabaseHandle)
      
      ;--------------------------------------------------------------------------------------------
      ; Retrieve all returned lines of data
      ;--------------------------------------------------------------------------------------------
      
      Picture\Title           = KillQuote(GetDatabaseString(Program\DatabaseHandle,  0))
      
      Picture\Artist          = KillQuote(GetDatabaseString(Program\DatabaseHandle,  1))
      
      Picture\Copyright       = KillQuote(GetDatabaseString(Program\DatabaseHandle,  2))
      
      Picture\Homepage        = KillQuote(GetDatabaseString(Program\DatabaseHandle,  3))
      
      Picture\Category        = KillQuote(GetDatabaseString(Program\DatabaseHandle,  4))
      
      Picture\Subcategory     = KillQuote(GetDatabaseString(Program\DatabaseHandle,  5))
      
      Picture\Comment         = KillQuote(GetDatabaseString(Program\DatabaseHandle,  6))
      
      Picture\Directory       = KillQuote(GetDatabaseString(Program\DatabaseHandle,  7))
      
      Picture\Filename        = KillQuote(GetDatabaseString(Program\DatabaseHandle,  8))
      
      Picture\MD5Fingerprint  =           GetDatabaseString(Program\DatabaseHandle,  9)
      
      Picture\Created         =           GetDatabaseString(Program\DatabaseHandle, 10)
      
      Picture\Modified        =           GetDatabaseString(Program\DatabaseHandle, 11)
      
      Picture\Accessed        =           GetDatabaseString(Program\DatabaseHandle, 12)
      
      Picture\Archived        =           GetDatabaseString(Program\DatabaseHandle, 13)
      
      Picture\Horizontal      =           GetDatabaseString(Program\DatabaseHandle, 14)
      
      Picture\Vertical        =           GetDatabaseString(Program\DatabaseHandle, 15)
      
      Picture\Depth           =           GetDatabaseString(Program\DatabaseHandle, 16)
      
      Picture\Favourite       =           GetDatabaseString(Program\DatabaseHandle, 17) 
      
      Picture\Locked          =           GetDatabaseString(Program\DatabaseHandle, 18) 
      
      Picture\Deleted         =           GetDatabaseString(Program\DatabaseHandle, 19) 
      
      Picture\RecordId        =           GetDatabaseString(Program\DatabaseHandle, 20)
      
      ;--------------------------------------------------------------------------------------------
      ; Send data to the re-useable string display as if in add mode
      ;--------------------------------------------------------------------------------------------
      
      DisplayTitleString("AddMode", PseudoCounter.i)
      
      ;--------------------------------------------------------------------------------------------
      ; Increment the line counter
      ;--------------------------------------------------------------------------------------------
      
      PseudoCounter.i + 1
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Wend
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    FinishDatabaseQuery(Program\DatabaseHandle)
    
    ;----------------------------------------------------------------------------------------------
    ; Lock the list form to prevent it greying out or flickering during the update
    ;----------------------------------------------------------------------------------------------
    
    LockWindowUpdate_(0)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If PseudoCounter.i <> 0
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetGadgetState(#Gadget_PiccyDb_Titles, 0)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      SetInfoBarArea("Records", #EmptyString, Str(PseudoCounter.i))
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      PostEvent(#PB_Event_Gadget, #Window_PiccyDb, #Gadget_PiccyDb_Titles, #PB_EventType_Change)
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings", "Error", "The database query failed to be executed.", "SearchPictures()")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 208
; FirstLine = 192
; Folding = -
; EnableXP