﻿;==============================================================================================================================================================================
; Show a bigger version of the stored picture
;==============================================================================================================================================================================

Procedure ViewCurrentPicture()
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  Program\CurrentLine = GetGadgetState(#Gadget_PiccyDb_Titles)
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  If Program\CurrentLine  <> #NothingSelected
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    Program\CurrentRecord = GetGadgetItemText(#Gadget_PiccyDb_Titles, Program\CurrentLine,  #RecordColumn)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If Program\CurrentRecord  <> #EmptyString
      
      ;--------------------------------------------------------------------------------------------
      ; Check if an existing window is opened
      ;--------------------------------------------------------------------------------------------
      
      If Program\WindowMutex <> #True
        
        ;------------------------------------------------------------------------------------------
        ; Try to open the data form window
        ;------------------------------------------------------------------------------------------
        
        If Window_PiccyViewer()
          
          ;----------------------------------------------------------------------------------------
          ; Window was opened so set mutex to prevent other windows from opening
          ;----------------------------------------------------------------------------------------
          
          Program\WindowMutex = #True
          
          ;----------------------------------------------------------------------------------------
          ; Prevent user input on the main window
          ;----------------------------------------------------------------------------------------
          
          DisableWindow(#Window_PiccyDb, #True)
          
          ;----------------------------------------------------------------------------------------
          ; Setup the common add window message
          ;----------------------------------------------------------------------------------------
          
          Message.s = "View Current Picture"
          
          ;----------------------------------------------------------------------------------------
          ; Set the last window message for the closure routine later
          ;----------------------------------------------------------------------------------------
          
          Program\LastWindow = Message.s
          
          ;----------------------------------------------------------------------------------------
          ; Show new record number and status in the data window
          ;----------------------------------------------------------------------------------------
          
          SetWindowTitle(#Window_PiccyViewer, Message.s)
          
          ;----------------------------------------------------------------------------------------
          ; Add the fast form close keyboard shortcut
          ;----------------------------------------------------------------------------------------
          
          AddKeyboardShortcut(#Window_PiccyViewer, #PB_Shortcut_Escape,               #Shortcut_CloseViewer)
          
          AddKeyboardShortcut(#Window_PiccyViewer, #PB_Shortcut_Alt | #PB_Shortcut_X, #Shortcut_ExitViewer)

          ;----------------------------------------------------------------------------------------
          ;
          ;----------------------------------------------------------------------------------------
          
          QueryString.s = "SELECT m.Title, m.Horizontal, m.Vertical, n.Picture "
          
          QueryString.s + "FROM PictureInfo AS m, PictureData AS n "
          
          QueryString.s + "WHERE n.Record_Id = m.Record_Id "      
          
          QueryString.s + "AND m.Record_Id = '" + Program\CurrentRecord + "'"
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
          If DatabaseQuery(Program\DatabaseHandle, QueryString.s) <> #DatabaseQueryFail
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            While NextDatabaseRow(Program\DatabaseHandle)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              Picture\Title           = KillQuote(GetDatabaseString(Program\DatabaseHandle,   0))
              
              Picture\Horizontal      =           GetDatabaseString(Program\DatabaseHandle,   1)
              
              Picture\Vertical        =           GetDatabaseString(Program\DatabaseHandle,   2)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              Picture_Length.i        =           DatabaseColumnSize(Program\DatabaseHandle,  3)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              If Picture_Length.i <> #NoDataFound
                
                *PhotoBlobBuffer      =           AllocateMemory(Picture_Length.i)
                
                BlobResult.i          =           GetDatabaseBlob(Program\DatabaseHandle, 3, *PhotoBlobBuffer, Picture_Length.i)
                
              EndIf
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
            Wend
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            FinishDatabaseQuery(Program\DatabaseHandle)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            SetWindowTitle(#Window_PiccyViewer, GetWindowTitle(#Window_PiccyViewer) + " - Title ("  + Picture\Title + ")")
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            WindowsFrameWidth.i   = (WindowWidth(#Window_PiccyViewer,   #PB_Window_FrameCoordinate) - WindowWidth(#Window_PiccyViewer,  #PB_Window_InnerCoordinate))
            
            WindowsFrameHeigth.i  = (WindowHeight(#Window_PiccyViewer,  #PB_Window_FrameCoordinate) - WindowHeight(#Window_PiccyViewer, #PB_Window_InnerCoordinate))
            
            TaskBarHeight.i       = GetWindowTitleBarDetails(#Window_PiccyViewer)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            PictureWidth.i        = Val(Picture\Horizontal)
            
            PictureHeight.i       = Val(Picture\Vertical)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            MaxInnerWidth.i       = Program\DesktopWidth  - WindowsFrameWidth.i
            
            MaxInnerHeight        = Program\DesktopHeight - WindowsFrameHeigth.i - TaskBarHeight.i
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            WidthFactor.f   = 1.0
            
            HeightFactor.f  = 1.0
            
            Factor.f        = 1.0
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            If PictureWidth.i > MaxInnerWidth.i
              
              WidthFactor.f   = MaxInnerWidth.i / PictureWidth.i
              
            EndIf
            
            If PictureHeight.i > MaxInnerHeight.i
              
              HeightFactor.f   = MaxInnerHeight.i / PictureHeight.i
              
            EndIf
            
            If WidthFactor.f < HeightFactor.f
              
              Factor.f       = WidthFactor.f
              
            EndIf
            
            If HeightFactor.f < WidthFactor.f
              
              Factor.f        = HeightFactor.f
              
            EndIf
            
            ;--------------------------------------------------------------------------------------
            ;
            ;--------------------------------------------------------------------------------------
            
            NewWindowWidth.i  = PictureWidth.i  * Factor.f
            
            NewWindowHeight.i = PictureHeight.i * Factor.f            
            
            ;--------------------------------------------------------------------------------------
            ;
            ;--------------------------------------------------------------------------------------
            
            If BlobResult.i <> #NoBlobFound
              
              PictureHandle.i = CatchImage(#PB_Any, *PhotoBlobBuffer)
              
              If PictureHandle.i  <> #NoPictureHandle
                
                ResizeWindow(#Window_PiccyViewer, (Program\DesktopWidth - NewWindowWidth.i - WindowsFrameWidth.i) / 2, (Program\DesktopHeight - NewWindowHeight.i - WindowsFrameHeigth.i - TaskBarHeight.i) / 2, NewWindowWidth.i, NewWindowHeight.i)
                
                ResizeImage(PictureHandle.i, NewWindowWidth.i, NewWindowHeight.i, #PB_Image_Smooth)
                
                SetGadgetState(#Gadget_PiccyViewer_picture, ImageID(PictureHandle.i))
                
              EndIf
              
            Else
              
              ResizeImage(#Image_PiccyViewer_picture, #MainPictureWidth, #MainPictureHeight, #PB_Image_Smooth)
              
              SetGadgetState(#Gadget_PiccyViewer_picture,     ImageID(#Image_PiccyViewer_picture))
              
            EndIf
            
            ;--------------------------------------------------------------------------------------
            ;
            ;--------------------------------------------------------------------------------------
            
            SetInfoBarArea("Number",  #EmptyString, Picture\RecordId)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
          Else
            
            SetInfoBarArea("Headings", "Error", "Database query failed or was empty: " + DatabaseError(), "ViewCurrentPicture")
            
          EndIf
          
          ;----------------------------------------------------------------------------------------
          ; Show new record number and status in the main window
          ;----------------------------------------------------------------------------------------
          
          SetInfoBarArea("Headings", "Info", Message.s  + " to the picture database")
          
          ;----------------------------------------------------------------------------------------
          ; Make sure the data form window is topmost
          ;----------------------------------------------------------------------------------------
          
          SetActiveWindow(#Window_PiccyViewer)
          
          ;----------------------------------------------------------------------------------------
          ; Make sure the version field is selected
          ;----------------------------------------------------------------------------------------
          
          SetActiveGadget(#Gadget_PiccyViewer_Picture)
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
        Else
          
          SetInfoBarArea("Headings", "Error", "The program window could not be opened.", "ViewCurrentPicture")
          
        EndIf
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
      Else
        
        SetInfoBarArea("Headings", "Warn", "Another program window is still open, close that one first.", "ViewCurrentPicture")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      ResizeImage(#Image_PiccyViewer_picture, #MainPictureWidth, #MainPictureHeight, #PB_Image_Smooth)
      
      SetInfoBarArea("Headings", "Error", "No record number found on line: " + Str(Program\CurrentLine), "ViewCurrentPicture")
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings", "Info", "There is no current line selected", "ViewCurrentPicture")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 7
; Folding = -
; EnableAsm
; EnableUnicode
; EnableXP