﻿;==============================================================================================================================================================================
; Try to open the system database and create missing tables
;==============================================================================================================================================================================

Procedure OpenSystemDatabase()
  
  ;------------------------------------------------------------------------------------------------
  ; Create the database if it doesn't already exist.
  ;------------------------------------------------------------------------------------------------
  
  FileHandle.i = OpenFile(#PB_Any, Program\DatabaseName)
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
  If FileHandle.i
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    CloseFile(FileHandle.i)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    Program\DatabaseHandle = OpenDatabase(#PB_Any, Program\DatabaseName, #EmptyString, #EmptyString)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If Program\DatabaseHandle
      
      ;--------------------------------------------------------------------------------------------
      ; Turn on auto database vacuum
      ;--------------------------------------------------------------------------------------------
      
      If Not DatabaseUpdate(Program\DatabaseHandle, "PRAGMA auto_vacuum = on")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the PictureInfo table out
      ;--------------------------------------------------------------------------------------------
      
      DatabaseUpdate.s = "CREATE TABLE IF NOT EXISTS PictureInfo("
      
      DatabaseUpdate.s + "Title TEXT, Artist TEXT, Copyright TEXT, Homepage TEXT, "
      
      DatabaseUpdate.s + "Category TEXT, Subcategory TEXT, Comment TEXT, Directory TEXT, "
      
      DatabaseUpdate.s + "Filename TEXT, MD5Fingerprint TEXT, Created TEXT, Modified TEXT, "
      
      DatabaseUpdate.s + "Accessed TEXT, Archived TEXT, Horizontal TEXT, Vertical TEXT, "
      
      DatabaseUpdate.s + "Depth TEXT, Favourite TEXT, Locked TEXT, Deleted TEXT, "
      
      DatabaseUpdate.s + "Record_Id INTEGER PRIMARY KEY AUTOINCREMENT, "
      
      DatabaseUpdate.s + "UNIQUE (Md5Fingerprint) ON CONFLICT FAIL)"
      
      If Not DatabaseUpdate(Program\DatabaseHandle, DatabaseUpdate.s)
        
        ;Debug DatabaseUpdate.s  + "  --  "  + DatabaseError()
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the PictureData table out
      ;--------------------------------------------------------------------------------------------
      
      DatabaseUpdate.s = "CREATE TABLE PictureData("
      
      DatabaseUpdate.s + "Picture_Id INTEGER PRIMARY KEY AUTOINCREMENT, "
      
      DatabaseUpdate.s + "Picture BLOB, "
      
      DatabaseUpdate.s + "Record_Id INTEGER, "
      
      DatabaseUpdate.s + "FOREIGN KEY(Record_Id) REFERENCES PictureInfo(Record_Id))"     
      
      If Not DatabaseUpdate(Program\DatabaseHandle, DatabaseUpdate.s)
        
        ;Debug DatabaseUpdate.s  + "  --  "  + DatabaseError()
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Create the index on PictureInfo
      ;--------------------------------------------------------------------------------------------
      
      DatabaseUpdate.s = "CREATE INDEX IF NOT EXISTS PictureData_index ON PictureInfo("
      
      DatabaseUpdate.s + "Title, Artist, Copyright, Homepage, Category, Comment)"
      
      If Not DatabaseUpdate(Program\DatabaseHandle, DatabaseUpdate.s)
        
        ;Debug DatabaseUpdate.s  + "  --  "  + DatabaseError()
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the appointments table out
      ;--------------------------------------------------------------------------------------------
      
      DatabaseUpdate.s = "CREATE TABLE IF NOT EXISTS Categories("
      
      DatabaseUpdate.s + "Category TEXT, Itemcount TEXT, "
      
      DatabaseUpdate.s + "Record_Id INTEGER PRIMARY KEY AUTOINCREMENT, "
      
      DatabaseUpdate.s + "UNIQUE(Category))"
      
      If Not DatabaseUpdate(Program\DatabaseHandle, DatabaseUpdate.s) = 0
        
        ;Debug DatabaseUpdate.s  + "  --  "  + DatabaseError()
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Write the appointments table out
      ;--------------------------------------------------------------------------------------------
      
      DatabaseUpdate.s = "CREATE TABLE IF NOT EXISTS Options("
      
      DatabaseUpdate.s + "TitleClock TEXT, StickyWindow TEXT, ScreenSnap TEXT, LastSearch TEXT, "
      
      DatabaseUpdate.s + "Record_Id INTEGER PRIMARY KEY AUTOINCREMENT)"

      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
      If DatabaseUpdate(Program\DatabaseHandle, DatabaseUpdate.s)
        
        If CountRecords("Record_Id", "Options") = "0"
          
          DatabaseUpdate.s = "INSERT INTO Options(TitleClock, StickyWindow, ScreenSnap, LastSearch)"
          
          DatabaseUpdate.s + "VALUES('0', '0', '0', '')"
          
          DatabaseUpdate(Program\DatabaseHandle, DatabaseUpdate.s)
          
        EndIf
        
      Else
        
        MessageRequester("Table creation error", "Could not create tables in database.")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      MessageRequester("Database open error", "Could not open database file in database mode.", #PB_MessageRequester_Ok)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    MessageRequester("Database open error", "Could not open or create raw database file.", #PB_MessageRequester_Ok)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 76
; FirstLine = 66
; Folding = -
; EnableXP