﻿;============================================================================================================================================================
; Generic modules used by all programs
;============================================================================================================================================================

Declare.s FormatMenu(HeadingString.s, ShortcutString.s, FieldLen.i)                                 ; Format menu text and shortcut strings to nice length
Declare.s GetShortcutText(Constant.i)                                                               ; Get the text of the associated shortcut constant. SROD
Declare.i GetWindowTitleBarDetails(Window.i)                                                        ; Get the current windows title bar height
Declare.s KillQuote(Instring.s)                                                                     ; Kill double quotes in strings for display purposes
Declare   LastLine(Gadget.i, LineNumber.i)                                                          ; Go to the last line of a ListIconGadget
Declare.s MakeSureDirectoryPathExists(Directory.s)                                                  ; Need a unicode aware version of the API directory creator
Declare   MixedComboCaseEx(Gadget.i)                                                                ; First letter uppercase in a combo box. srod!.
Declare   MixedStringCase(Gadget.i)                                                                 ; First letter uppercase in a string box. srod!
Declare.s ProperCaseString(StringToBeFlipped.s)                                                     ; Flip a mixed string into all proper case
Declare   RemoveBorders(GadgetConstant.i)                                                           ; Remove borders from various gadgets
Declare.s RepQuote(Instring.s)                                                                      ; Uncle Berikco's routine to properly replace single quotes with double for SQL passing
Declare   StringFirstUpper(GadgetId.i)                                                              ; Convert the first character of a string to uppercase
Declare.s TextToXML(TextString.s)                                                                   ; Replace bad characters with XML compatible ones. Thorsten Hoeppner
Declare.s XMLToText(XMLString.s)                                                                    ; Strip illegal characters from text strings

;============================================================================================================================================================
; Form and list handling
;============================================================================================================================================================

Declare   SetHoverIcons(Gadget.i, Image.i, State.s)                                                 ; Set the correct icons to the selected hoverable gadget

;============================================================================================================================================================
; Custom include files
;============================================================================================================================================================

Declare   CheckEnterGadget()                                                                        ; Check which gadget had the focus at the time ENTER was pressed
Declare   CloseMyWindow(Window.i)                                                                   ; Fade the window out gently, close it and reset the mutex
Declare.s IsoDate(DateString.s, Direction.s)                                                        ; Convert an ISO format date to Australian and back
Declare   ReadProgramOptions()                                                                      ; Read the program toggles from the database
Declare   SaveProgramOptions()                                                                      ; Save all the program options whenever you need to
Declare   SetInfoBarArea(FieldName.s, FieldStatus.s, MessageContent.s = "0", ModuleName.s = "")     ; Send messages and error reports to the fake status bar area
Declare   StatusBarTip(Window.i, Section.s)                                                         ; Custom statusbar tooltip messages
Declare   TitleBarClock(ObjectHandle.i, Message.i, EventNumber.i, TimePeriod.i)                     ; Run an asynchronous clock in the window title bar
Declare   WindowCallback(WindowID.i, Message.i, wParam.i, lParam.i)                                 ; Custom module for colours, deletions etc

;==========================================================================================================================================================
; Various program toggles
;==========================================================================================================================================================

Declare   ToggleStickyWindow()                                                                      ; Change the desktop from on top to under others
Declare   ToggleTitleClock()                                                                        ; Turn the titlebar clock on or off
Declare   ToggleScreenSnap()                                                                        ; Turn snapping to screen borders on and off

;==========================================================================================================================================================
; Minimising and maximising the program window
;==========================================================================================================================================================

Declare   HideProgramWindow()                                                                       ; Hide the program window
Declare   ShowProgramWindow()                                                                       ; Show the program window

;==========================================================================================================================================================
; Database include files
;==========================================================================================================================================================

Declare   BackupDatabase()                                                                          ; Backup the current database to a named day of the week
Declare.s CountRecords(TableField.s, TableName.s)                                                   ; Count the number of records in an SQLite database
Declare.s DatabaseLastInsertRowId()                                                                 ; Get the ID of the last inserted record
Declare   FillCombo(Gadget.i, DatabaseQuery.s, ColumnIcon.i = 0)                                    ; Fill a combobox gadget from a linked list, SQLite version
Declare.s LastRecord(TableField.s, TableName.s)                                                     ; Find the last record number in the database, not necessarily the last record though due to deletions (fang)
Declare   OpenSystemDatabase()                                                                      ; Open or create the stystem database and create any needed tables
Declare.s SetSearchQuery(SearchOperator.s, SearchString.s)                                          ; Alias the search type text to SQLite operators
Declare   VacuumDatabase()                                                                          ; Clean all deleted items from the database immediately

;==========================================================================================================================================================
; Categories management
;==========================================================================================================================================================

Declare   LoadCategories()                                                                          ; Load all the categories into the category bar
Declare   ShowCategory()                                                                            ; Show the items that belong to a particular category
Declare   SortCategoryEntries()                                                                     ; Sort the category list after an add or edit

Declare   ChangeCategory()                                                                          ; Change the category of a title by dragging and dropping it onto the category bar
Declare   DragToCategory()                                                                          ; Change the category of a title by dragging and dropping it onto the category bar

Declare   AddCategory()                                                                             ; Add a new category to the database
Declare   CopyCategory()                                                                            ; Copy the current category to the clipboard
Declare   DeleteCategory()                                                                          ; Delete the selected category
Declare   EditCategory()                                                                            ; Edit the selected category
Declare   ExportCategories()                                                                        ; Import a list of categories from a text file
Declare   ImportCategories()                                                                        ; Export the list of categories to disk
Declare   SaveCategory()                                                                            ; Save the changed category data to the database
Declare   UpdateCategoryItemCount(CategoryName.s)                                                   ; Update the category itemcount field each time we add, change or delete addresses or categories

;==========================================================================================================================================================
; All data handling routines
;==========================================================================================================================================================

Declare   AttachPicture()                                                                           ; Attach a new picture to the record editor form
Declare   DisplayTitleString(DisplayMode.s, LineNumber.i)                                           ; Handle all list display jobs from add, edit, list, import modes etc
Declare   LoadPictures()                                                                            ; Load all pictures at startup

Declare   AddNewPicture()                                                                           ; Add a new picture and details to the database
Declare   AddPictureFolder()                                                                        ; Add an entire folder of pictures
Declare   DeleteCurrentPicture()                                                                    ; Delete the currently selected picture
Declare   CopyCurrentPicture()                                                                      ; Copy the currently selected picture to the system clipboard
Declare   DeleteCurrentPicture()                                                                    ; Delete the currently selected picture
Declare   EditCurrentPicture()                                                                      ; Edit the currently selected picture
Declare   ExportPictures()                                                                          ; Export all pictures to disk as an XML file
Declare   FavouriteCurrentPicture()                                                                 ; Mark the current picture as a favourite
Declare   ImportPictures()                                                                          ; Import pictures from disk
Declare   KillCurrentPicture()                                                                      ; Permanently delete the current picture
Declare   LockCurrentPicture()                                                                      ; Lock the current picture against editing
Declare   ProcessPictureNode(*MainNode, CurrentSublevel.i)                                          ; Process the current picture node data
Declare   SaveCurrentPictureToDisk()                                                                ; Save the new or edited picture data
Declare   SaveSelectedPicturesToDisk()                                                              ; Save all selected pictures to disk  
Declare   SaveCategoryPicturesToDisk()                                                              ; Save pictures in the current category to disk
Declare   SaveAllPicturesToDisk()                                                                   ; Save all pictures to disk
Declare   SavePictureData()                                                                         ; Save the current picture to disk
Declare   SearchPictures()                                                                          ; Show all the pictures in the database
Declare   ShowCurrentPicture()                                                                      ; Show the currently selected picture details

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

Declare   AboutProgram()                                                                            ; Show an 'about' program window
Declare   ShowProgramHelp()                                                                         ; Show available program help

; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 109
; FirstLine = 74
; EnableXP